@@ -64,7 +64,7 @@ for (i in 1:t) {
  plot(actions.m[1,],ylim=yl,xlab="time",ylab="Action Strength",col="black",typ="l",main="Actions over time",lwd=2)
  for (j in 2:n) {points(actions.m[j,],lty=j,col=colours[j],typ="l",lwd=2)}
  
-if(FALSE){
+if(TRUE){#keep true to allow for state-space diagrams}
 #now do various types of plots, depending upon the type of plot desired
 
 plots <- 1
@@ -114,7 +114,7 @@ class(results) <- c("psych","cta")
 return(results)
 }
 
-"print.psych.cta" <- 
+"print_psych.cta" <- 
 function(x,digits=2,all=NULL) {
 if(all) {unclass(x)
    print(x)} else {
